@@ -44,3 +44,5 @@
 #undef HAVE_PASSWDEXPIRED
 #undef HAVE_CHPASS
 #undef HAVE_LOGINRESTRICTIONS
+#undef HAVE_LOGINDEVPERM
+#undef HAVE_ADT
